#
# spec file for package python-path.py
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-path.py
Version:        8.1.1
Release:        1.1
Summary:        A module wrapper for os.path
License:        MIT
Group:          Development/Languages/Python
Url:            http://github.com/jaraco/path.py
Source:         http://pypi.python.org/packages/source/p/path.py/path.py-%{version}.tar.gz
BuildRequires:  python-devel
BuildRequires:  python-pytest
BuildRequires:  python-pytest-runner >= 2.6
BuildRequires:  python-setuptools
BuildRequires:  python-setuptools_scm
BuildRequires:  python-appdirs
Requires:       python-appdirs
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
BuildRequires:  python-importlib
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
The path.py package implements a path objects as first-class
entities, allowing common operations on files to be invoked
on those path objects directly.

%prep
%setup -q -n path.py-%{version}

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

%check
# need to set locale to avoid UnicodeEncodeError
export LANG=en_US.UTF-8
python setup.py test

%files
%defattr(-,root,root,-)
%doc CHANGES.rst README.rst
%{python_sitelib}/*

%changelog
* Wed Sep 16 2015 toddrme2178@gmail.com
- Update to version 8.1.1
  * Restored path.path with a DeprecationWarning.
  * Removed path.path. Clients must now refer to the canonical
    name, path.Path as introduced in 6.2.
  * Added support for resolving certain directories on a system to
    platform-friendly locations using the appdirs library.
  * In order to support "multipath" results, where multiple paths
    are returned in a single, os.pathsep-separated string, a new
    class MultiPath now represents those special results. This
    functionality is experimental and may change. Feedback is
    invited.
* Wed Aug 12 2015 toddrme2178@gmail.com
- Update to version 7.6
  - Pull Request #100: Add ``merge_tree`` method for merging
    two existing directory trees.
  - Uses `setuptools_scm <https://github.org/pypa/setuptools_scm>`_
    for version management.
- Update to version 7.5
  - #97: ``__rdiv__`` and ``__rtruediv__`` are now defined.
- Update to version 7.4
  - #93: chown now appears in docs and raises NotImplementedError if
    ``os.chown`` isn't present.
  - #92: Added compatibility support for ``.samefile`` on platforms without
    ``os.samefile``.
- Update to version 7.3
  - #91: Releases now include a universal wheel.
- Update to version 7.2
  - In chmod, added support for multiple symbolic masks (separated by commas).
  - In chmod, fixed issue in setting of symbolic mask with '=' where
    unreferenced permissions were cleared.
- Update to version 7.1
  - #23: Added support for symbolic masks to ``.chmod``.
- Update to version 7.0
  - The ``open`` method now uses ``io.open`` and supports all of the
    parameters to that function. ``open`` will always raise an ``OSError``
    on failure, even on Python 2.
  - Updated ``write_text`` to support additional newline patterns.
  - The ``text`` method now always returns text (never bytes), and thus
    requires an encoding parameter be supplied if the default encoding is not
    sufficient to decode the content of the file.
- Update to version 6.2
  - ``path`` class renamed to ``Path``. The ``path`` name remains as an alias
  for compatibility.
- Update to version 6.1
  - ``chown`` now accepts names in addition to numeric IDs.
- Update to version 6.0
  - Drop support for Python 2.5. Python 2.6 or later required.
  - Installation now requires setuptools.
- Update to version 5.3
  - Allow arbitrary callables to be passed to path.walk ``errors`` parameter.
    Enables workaround for issues such as #73 and #56.
- Update to version 5.2
  - #61: path.listdir now decodes filenames from os.listdir when loading
    characters from a file. On Python 3, the behavior is unchanged. On Python
    2, the behavior will now mimick that of Python 3, attempting to decode
    all filenames and paths using the encoding indicated by
    ``sys.getfilesystemencoding()``, and escaping any undecodable characters
    using the 'surrogateescape' handler.
- Update to version 5.1
  - #53: Added ``path.in_place`` for editing files in place.
- Update to version 5.0
  - ``path.fnmatch`` now takes an optional parameter ``normcase`` and this
    parameter defaults to self.module.normcase (using case normalization most
    pertinent to the path object itself). Note that this change means that
    any paths using a custom ntpath module on non-Windows systems will have
    different fnmatch behavior.
  - Issue #50: Methods that accept patterns (``listdir``, ``files``, ``dirs``,
    ``walk``, ``walkdirs``, ``walkfiles``, and ``fnmatch``) will now use a
    ``normcase`` attribute if it is present on the ``pattern`` parameter. The
    path module now provides a ``CaseInsensitivePattern`` wrapper for strings
    suitable for creating case-insensitive patterns for those methods.
- Update to version 4.4
  - Issue #44: _hash method would open files in text mode, producing
    invalid results on Windows. Now files are opened in binary mode, producing
    consistent results.
  - Issue #47: Documentation is dramatically improved with Intersphinx links
    to the Python os.path functions and documentation for all methods and
    properties.
- Update to version 4.3
  - Issue #32: Add ``chdir`` and ``cd`` methods.
- Update to version 4.2
  - ``open()`` now passes all positional and keyword arguments through to the
    underlying ``builtins.open`` call.
- Update to version 4.1
  - Native Python 2 and Python 3 support without using 2to3 during the build
    process.
- Update to version 4.0
  - Added a ``chunks()`` method to a allow quick iteration over pieces of a
    file at a given path.
  - Issue #28: Fix missing argument to ``samefile``.
  - Initializer no longer enforces `isinstance basestring` for the source
    object. Now any object that supplies ``__unicode__`` can be used by a
    ``path`` (except None). Clients that depend on a ValueError being raised
    for ``int`` and other non-string objects should trap these types
    internally.
  - Issue #30: ``chown`` no longer requires both uid and gid to be provided
    and will not mutate the ownership if nothing is provided.
- Update to version 3.2
  - Issue #22: ``__enter__`` now returns self.
- Update to version 3.1
  - Issue #20: `relpath` now supports a "start" parameter to match the
    signature of `os.path.relpath`.
- Update to version 3.0
  - Minimum Python version is now 2.5.
- Update to version 2.6
  - Issue #5: Implemented `path.tempdir`, which returns a path object which is
    a temporary directory and context manager for cleaning up the directory.
  - Issue #12: One can now construct path objects from a list of strings by
    simply using path.joinpath.
- Update to version 2.5
  - Issue #7: Add the ability to do chaining of operations that formerly only
    returned None.
  - Issue #4: Raise a TypeError when constructed from None.
- Update to version 2.4
  - No upstream changelog
* Mon Jul 23 2012 saschpe@suse.de
- Initial version
